// -*-C++-*-
//
// File:      ChoiceChildParameters.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue May 21 15:36:25 MEST 2002

#include "ChoiceChildParameters.h"
#include "Parameter.h"         // Application headers

// BEGIN private classes
class ParentParameter : public ParameterView
{
public:
  ParentParameter(Parameter* parent, const std::string& imply)
    : _parent(parent), _implicit(imply)
    {
    }
  ~ParentParameter(){}
  bool isSticky() {return true;}
  void updateView() {
    /*
      Only a child can set a parent implicitly, but avoid updating the value,
      if the value was set explicitly on the commandline
    */
    if (!_parent->isSet()) _parent->setNewValue( _implicit);
  }
  
private:
  Parameter* _parent;
  std::string  _implicit;
};
// END private classes


ChoiceChildParameters::ChoiceChildParameters(Parameter* parent)
  : _parent(parent)
{
}

ChoiceChildParameters::~ChoiceChildParameters()
{
}

void ChoiceChildParameters::add(const std::string& choice,Parameter* child)
{
  if (child) {
    (*this)[choice].push_back(child);
    
    // add a notifier to the child
    child->addView(new ParentParameter(_parent,choice));
  }
  else (*this)[choice];
}

std::list<std::string >  ChoiceChildParameters::choices()
{
  std::list<std::string > c;
  if ( empty() ) return c;
  
  // extract all choices from the map...
  for (const_iterator it=begin();it!=end();it++) c.push_back( (*it).first );
  return c;
}
