/*****************************************************************************
 *
 *  IntParameter.h                              XMM Science Analysis Subsystem
 *
 *  Integer task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: IntParameter.h,v 1.11 2002/12/17 17:53:49 jbakker Exp $
 *
 *****************************************************************************/

#ifndef INTPARAMETER_H
#define INTPARAMETER_H

#include "Parameter.h"

#include <string>                // C++ headers
#include <iostream>


//================================================================
//  Class IntParameter
//================================================================

class IntParameter : public Parameter
{
public:

    // Construction
    IntParameter() : _value(0),_default(0) {}
    IntParameter* clone() { return new IntParameter(*this); }

    // Value
    int         intValue() const { return _value; }
    bool        setNewValue(const std::string& value);
    bool        setValue(int value);
    ParamType   getType() const {return Parameter::Int;}
    const char* getTypeName() const { return "int"; }

    // Default
    int        defaultValue() const {return _default;}
    bool       setNewDefault(const std::string& value);
    bool       setDefault(int value);
    void       revertToDefault();

    // Formatting
    std::string     asString() const;
    std::string     defaultAsString() const;

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.intValue());}


    // Parsing
    bool parse(const std::string& str, int& value);

    // Validation
    bool isValid(int n) const;
    void reportRangeError(const std::string& valueString);

    // Member data
    int            _value;
    int            _default;
};

#endif
