/*****************************************************************************
 *
 *  ParamInfoSet.h                              XMM Science Analysis Subsystem
 *
 *  ParameterInfo for a set of tasks.
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *  (c) 2000  ESA  -  Reimplemented by Jorgo Bakker, BSC
 *
 *  $Id: ParamInfoSet.h,v 1.4 2003/02/10 15:19:08 jbakker Exp $
 *
 *****************************************************************************/

#ifndef PARAMINFOSET_H
#define PARAMINFOSET_H

#include "Parameter.h"            // Application headers
#include "ParameterInfo.h"

#include <string>                 // C++ headers
#include <map>


//================================================================
//  Class ParamInfoSet [SINGLETON]
//
//  There is a single instance of this class which caches the
//  parameters associated with a task.
//================================================================

class ParamInfoSet
{
public:

    // Type definitions
    typedef std::map<std::string, ParameterInfo*, std::less<std::string> > ParamInfoMap;

    // Return the sole instance of this class
    static ParamInfoSet* instance();

    // Return the ParameterInfo for the specified task
    ParameterInfo* getParamInfo(const std::string& taskName);

    // Save the ParameterInfo
    void saveParamInfo(ParameterInfo*);

    // Reset all parameters of all tasks to their default values
    void resetParamInfo();

    // Reset parameters of specified task to their default values
    void resetParamInfo(const std::string& taskName);

private:
    ParamInfoSet();
    ParamInfoSet(const ParamInfoSet&);      // copy constructor disabled!
    ParamInfoSet& operator=(const ParamInfoSet&); // assignment disabled!
    ParamInfoMap _infoMap;          // Maps task name onto ParameterInfo 

    static ParamInfoSet* _infoSet;  // The sole instance of this class
};

#endif
