/**-*-C++-*-*******************************************************************
 *
 *  StringParameter.h                           XMM Science Analysis Subsystem
 *
 *  String task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: StringParameter.h,v 1.11 2002/12/17 17:53:50 jbakker Exp $
 *
 *****************************************************************************/

#ifndef STRINGPARAMETER_H
#define STRINGPARAMETER_H

#include "Parameter.h"           // headers
#include <string>


//================================================================
//  Class StringParameter
//================================================================

class StringParameter : public Parameter
{
public:
    // Construction
    StringParameter* clone() { return new StringParameter(*this); }

    // Value
    const std::string&  stringValue() const { return _value; }
    bool           setNewValue(const std::string& value);
    virtual bool   setValue(const std::string& value);
    virtual bool   setValue(const char* s) { return setValue(std::string(s)); }
    ParamType      getType() const {return Parameter::String;}
    const char*    getTypeName() const { return "string"; }

    // Default
    const std::string&  defaultValue() const {return _default;}
    bool           setNewDefault(const std::string& value);
    virtual bool   setDefault(const std::string& value);
    void           revertToDefault();

    // Formatting
    virtual std::string asString() const;
    std::string     defaultAsString() const;

protected:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.stringValue());}

    // Parsing
    bool parse(const std::string& str, std::string& value);

    // Validation
    virtual bool isValid(const std::string& value) const;
    virtual void reportRangeError(const std::string& valueString);

    // Member data
    std::string _value;
    std::string _default;

};

#endif

